@@ -1,7 +1,7 @@
 package Data::Sah::CoerceJS;
 
-our $DATE = '2016-06-29'; # DATE
-our $VERSION = '0.018'; # VERSION
+our $DATE = '2016-09-25'; # DATE
+our $VERSION = '0.019'; # VERSION
 
 use 5.010001;
 use strict;
@@ -94,12 +94,12 @@ sub gen_coercer {
 
     sub {
         require File::Temp;
-        require JSON::MaybeXS;
+        require JSON;
         #require String::ShellQuote;
 
         my $data = shift;
 
-        state $json = JSON::MaybeXS->new->allow_nonref;
+        state $json = JSON->new->allow_nonref;
 
         # code to be sent to nodejs
         my $src = "var coercer = $code;\n\n".
@@ -130,7 +130,7 @@ Data::Sah::CoerceJS - Generate coercer code
 
 =head1 VERSION
 
-This document describes version 0.018 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2016-06-29.
+This document describes version 0.019 of Data::Sah::CoerceJS (from Perl distribution Data-Sah-Coerce), released on 2016-09-25.
 
 =head1 SYNOPSIS
 
